==> lxqt-powermanagement_0.14.1.orig.tar.xz: lxqt-powermanagement-0.14.1/config/translations/lxqt-config-powermanagement_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>Ρυθμίσεις του επόπτη συσσωρευτή</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>&amp;Ενεργοποίηση του επόπτη του συσσωρευτή</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>Προειδοποίηση:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> δευτερόλεπτα</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>Το επίπεδο είναι χαμηλό στο:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="111"/>
        <source>Use icons from theme:</source>
        <translation>Χρήση των εικονιδίων από το θέμα:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="125"/>
        <location filename="../batterywatchersettings.cpp" line="93"/>
        <source>Preview</source>
        <translation>Προεπισκόπηση</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="162"/>
        <source>Charging</source>
        <translation>Φόρτιση</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="200"/>
        <source>Discharging</source>
        <translation>Αποφόρτιση</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>Όταν η φόρτιση είναι χαμηλή:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>Εμφάνιση του εικονιδίου:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="93"/>
        <source>built in</source>
        <translation>ενσωματωμένο</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="98"/>
        <source>Level: %1%</source>
        <translation>Επίπεδο: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="17"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>Ενεργοποίηση του επόπτη α&amp;δράνειας</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="38"/>
        <source>When idle then:</source>
        <translation>Σε κατάσταση αδράνειας:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="57"/>
        <source>Idle time:</source>
        <translation>Χρόνος αδράνειας:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="70"/>
        <source> minutes</source>
        <translation> λεπτά</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="83"/>
        <source> seconds</source>
        <translation> δευτερόλεπτα</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../lidwatchersettings.ui" line="23"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>Ενεργοποίηση του επόπτη &amp;καλύμματος</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="38"/>
        <source>Action when lid is closed</source>
        <translation>Ενέργεια κατά το κλείσιμο του καλύμματος</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="50"/>
        <location filename="../lidwatchersettings.ui" line="115"/>
        <source>On Battery</source>
        <translation>Σε συσσωρευτή</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="58"/>
        <source>Nothing</source>
        <translation>Τίποτα</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="63"/>
        <source>Suspend</source>
        <translation>Αναστολή</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="68"/>
        <source>Hibernate</source>
        <translation>Νάρκη</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="73"/>
        <source>Shut down</source>
        <translation>Τερματισμός</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="81"/>
        <location filename="../lidwatchersettings.ui" line="125"/>
        <source>On AC</source>
        <translation>Σε τροφοδοτικό AC</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="94"/>
        <source>When &amp;using external monitor</source>
        <translation>Όταν χρησιμοποιείται εξωτερική ο&amp;θόνη</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="36"/>
        <source>Power Management Settings</source>
        <translation>Ρυθμίσεις της διαχείρισης ενέργειας</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="39"/>
        <source>Battery</source>
        <translation>Συσσωρευτής</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="43"/>
        <source>Lid</source>
        <translation>Κάλυμμα φορητού</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="47"/>
        <source>Idle</source>
        <translation>Αδρανής</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>Τίποτα</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="36"/>
        <source>Lock screen</source>
        <translation>Κλείδωμα οθόνης</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="37"/>
        <source>Suspend</source>
        <translation>Αναστολή</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="38"/>
        <source>Hibernate</source>
        <translation>Νάρκη</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="39"/>
        <source>Shutdown</source>
        <translation>Τερματισμός</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="40"/>
        <source>Turn Off monitor(s)</source>
        <translation>Απενεργοποίηση των οθονών</translation>
    </message>
</context>
</TS>

==> lxqt-powermanagement_0.16.0.orig.tar.xz: lxqt-powermanagement-0.16.0/config/translations/lxqt-config-powermanagement_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>Ρυθμίσεις του επόπτη συσσωρευτή</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>&amp;Ενεργοποίηση του επόπτη του συσσωρευτή</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>Προειδοποίηση:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> δευτερόλεπτα</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>Το επίπεδο είναι χαμηλό στο:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="111"/>
        <source>Use icons from theme:</source>
        <translation>Χρήση των εικονιδίων από το θέμα:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="125"/>
        <location filename="../batterywatchersettings.cpp" line="93"/>
        <source>Preview</source>
        <translation>Προεπισκόπηση</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="162"/>
        <source>Charging</source>
        <translation>Φόρτιση</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="200"/>
        <source>Discharging</source>
        <translation>Αποφόρτιση</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>Όταν η φόρτιση είναι χαμηλή:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>Εμφάνιση του εικονιδίου:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="93"/>
        <source>built in</source>
        <translation>ενσωματωμένο</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="98"/>
        <source>Level: %1%</source>
        <translation>Επίπεδο: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="17"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>Ενεργοποίηση του επόπτη α&amp;δράνειας</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="34"/>
        <source>When idle then:</source>
        <translation>Σε κατάσταση αδράνειας:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="53"/>
        <location filename="../idlenesswatchersettings.ui" line="123"/>
        <source>Idle time:</source>
        <translation>Χρόνος αδράνειας:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="66"/>
        <source> minutes</source>
        <translation> λεπτά</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="79"/>
        <source> seconds</source>
        <translation> δευτερόλεπτα</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="94"/>
        <source>Enable Backlight Change</source>
        <translation>Ενεργοποίηση της αλλαγής του οπισθοφωτός</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="103"/>
        <source>Backlight (%):</source>
        <translation>Οπισθόφως (%):</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="130"/>
        <source>Minutes:Seconds</source>
        <translation>Λεπτά:Δευτερόλεπτα</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="150"/>
        <source>mm:ss</source>
        <translation>λλ:δδ</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="157"/>
        <source>Check backlight</source>
        <translation>Έλεγχος οπισθοφωτός</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="164"/>
        <source>On battery discharging </source>
        <translation>Κατά την αποφόρτιση του συσσωρευτή </translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../lidwatchersettings.ui" line="23"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>Ενεργοποίηση του επόπτη &amp;καλύμματος</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="38"/>
        <source>Action when lid is closed</source>
        <translation>Ενέργεια κατά το κλείσιμο του καλύμματος</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="50"/>
        <location filename="../lidwatchersettings.ui" line="115"/>
        <source>On Battery</source>
        <translation>Σε συσσωρευτή</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="58"/>
        <source>Nothing</source>
        <translation>Τίποτα</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="63"/>
        <source>Suspend</source>
        <translation>Αναστολή</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="68"/>
        <source>Hibernate</source>
        <translation>Νάρκη</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="73"/>
        <source>Shut down</source>
        <translation>Τερματισμός</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="81"/>
        <location filename="../lidwatchersettings.ui" line="125"/>
        <source>On AC</source>
        <translation>Σε τροφοδοτικό AC</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="94"/>
        <source>When &amp;using external monitor</source>
        <translation>Όταν χρησιμοποιείται εξωτερική ο&amp;θόνη</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="37"/>
        <source>Power Management Settings</source>
        <translation>Ρυθμίσεις της διαχείρισης ενέργειας</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Battery</source>
        <translation>Συσσωρευτής</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Lid</source>
        <translation>Κάλυμμα φορητού</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Idle</source>
        <translation>Αδρανής</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="52"/>
        <source>Power keys</source>
        <translation>Πλήκτρα τροφοδοσίας</translation>
    </message>
</context>
<context>
    <name>PowerKeysSettings</name>
    <message>
        <location filename="../powerkeyssettings.ui" line="14"/>
        <source>Form</source>
        <translation>Φόρμα</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="20"/>
        <source>Handle Power Keys</source>
        <translation>Διαχείριση των πλήκτρων τροφοδοσίας</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="26"/>
        <source>Power Key Action</source>
        <translation>Ενέργεια του πλήκτρου τροφοδοσίας</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="42"/>
        <source>Suspend Key Action</source>
        <translation>Ενέργεια του πλήκτρου αναστολής</translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="49"/>
        <source>Hibernate Key Action</source>
        <translation>Ενέργεια του πλήκτρου νάρκωσης</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>Τίποτα</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="36"/>
        <source>Ask</source>
        <translation>Ερώτηση</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="37"/>
        <source>Lock screen</source>
        <translation>Κλείδωμα οθόνης</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="38"/>
        <source>Suspend</source>
        <translation>Αναστολή</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="39"/>
        <source>Hibernate</source>
        <translation>Νάρκη</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="40"/>
        <source>Shutdown</source>
        <translation>Τερματισμός</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="41"/>
        <source>Turn Off monitor(s)</source>
        <translation>Απενεργοποίηση των οθονών</translation>
    </message>
</context>
</TS>
